@@ -5,6 +5,7 @@ from otools.logging.LoggingLevel import LoggingLevel
 from otools.core.Service import Service
 from otools.core.Dataframe import Dataframe
 from otools.status.StatusCode import StatusCode
+from otools.core.Trigger import Trigger
 import threading
 
 class Context ():
@@ -21,6 +22,7 @@ class Context ():
     self._services = {}
     self._services = {}
     self._dataframes = {}
+    self.__wd = None
     self._active = True
     self.running = False
   
@@ -47,8 +49,22 @@ class Context ():
       self.info (" * Adding Dataframe with name {}...".format(obj.name))
       obj.setContext(self)
       self._dataframes[obj.name] = obj
+    elif issubclass(type(obj), Trigger):
+      if obj.name in self._services:
+        message = "A service with name {} conflicts with this Trigger, skipping...".format(obj.name)
+        self.warning(message, self.__str__())
+        return self
+      self.info (" * Adding Trigger with name {}...".format(obj.name))
+      obj.setContext(self)
+      self._services[obj.name] = obj
     return self
 
+  def setWatchdog (self, wd):
+    self.__wd = wd
+
+  def getWatchdog (self):
+    return self.__wd
+
   def getService (self, serviceName):
     if serviceName in self._services:
       return self._services[serviceName]
@@ -101,10 +117,12 @@ class Context ():
 
   def main (self):
     for service in self._services:
+      self.__wd.startTimer(service, 'main', self.name)
       if self._services[service].main().isFailure():
         message = "Failed to main service {}".format(service)
         self.fatal(message, self.__str__())
         return StatusCode.FAILURE
+      self.__wd.resetTimer(service, 'main', self.name)
     return StatusCode.SUCCESS
 
   def loop (self):
